@@ -321,7 +321,19 @@ func (b *Builder) collectCompileEntriesBpkg(bpkg *BuildPackage) (
 
 	if len(bpkg.SourceDirectories) > 0 {
 		for _, relDir := range bpkg.SourceDirectories {
-			dir := bpkg.rpkg.Lpkg.BasePath() + "/" + relDir
+			var dir string
+			repo, path, err := newtutil.ParsePackageString(relDir)
+
+			if err != nil {
+				return nil, err
+			}
+
+			if repo != "" {
+				dir = "repos/" + repo + "/" + path
+			} else {
+				dir = bpkg.rpkg.Lpkg.BasePath() + "/" + relDir
+			}
+
 			if util.NodeNotExist(dir) {
 				return nil, util.NewNewtError(fmt.Sprintf(
 					"Specified source directory %s, does not exist.",
@@ -329,7 +341,8 @@ func (b *Builder) collectCompileEntriesBpkg(bpkg *BuildPackage) (
 			}
 			srcDirs = append(srcDirs, dir)
 		}
-	} else {
+	} else if len(bpkg.SourceFiles) == 0 {
+		// Add 'src/' automatically only if neither source dirs nor files are defined
 		srcDir := bpkg.rpkg.Lpkg.BasePath() + "/src"
 		if util.NodeNotExist(srcDir) {
 			// Nothing to compile.
@@ -350,6 +363,31 @@ func (b *Builder) collectCompileEntriesBpkg(bpkg *BuildPackage) (
 		entries = append(entries, subEntries...)
 	}
 
+	for _, filename := range bpkg.SourceFiles {
+		repo, path, err := newtutil.ParsePackageString(filename)
+
+		if err != nil {
+			return nil, err
+		}
+
+		if repo != "" {
+			filename = "repos/" + repo + "/" + path
+		} else {
+			filename = bpkg.rpkg.Lpkg.BasePath() + "/" + filename
+		}
+
+		if util.NodeNotExist(filename) {
+			return nil, util.NewNewtError(fmt.Sprintf(
+				"Specified source file %s, does not exist.",
+				filename))
+		}
+
+		entry, err := c.CollectSingleEntry(filename)
+		if err == nil {
+			entries = append(entries, *entry)
+		}
+	}
+
 	return entries, nil
 }
 
