@@ -35,6 +35,7 @@ import (
 type BuildPackage struct {
 	rpkg              *resolve.ResolvePackage
 	SourceDirectories []string
+	SourceFiles       []string
 	ci                *toolchain.CompilerInfo
 }
 
@@ -164,16 +165,22 @@ func (bpkg *BuildPackage) CompilerInfo(
 
 	// Package-specific injected settings get specified as C flags on the
 	// command line.
-	for k, _ := range bpkg.rpkg.Lpkg.InjectedSettings() {
+	for _, k := range bpkg.rpkg.Lpkg.InjectedSettings().Names() {
 		ci.Cflags = append(ci.Cflags, syscfg.FeatureToCflag(k))
 	}
 
 	ci.IgnoreFiles = []*regexp.Regexp{}
 
 	ignPats, err := bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
-		"pkg.ign_files", settings)
+		"pkg.ignore_files", settings)
 	util.OneTimeWarningError(err)
 
+	if len(ignPats) == 0 {
+		ignPats, err = bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
+			"pkg.ign_files", settings)
+		util.OneTimeWarningError(err)
+	}
+
 	for _, str := range ignPats {
 		re, err := regexp.Compile(str)
 		if err != nil {
@@ -186,9 +193,15 @@ func (bpkg *BuildPackage) CompilerInfo(
 	ci.IgnoreDirs = []*regexp.Regexp{}
 
 	ignPats, err = bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
-		"pkg.ign_dirs", settings)
+		"pkg.ignore_dirs", settings)
 	util.OneTimeWarningError(err)
 
+	if len(ignPats) == 0 {
+		ignPats, err = bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
+			"pkg.ign_dirs", settings)
+		util.OneTimeWarningError(err)
+	}
+
 	for _, str := range ignPats {
 		re, err := regexp.Compile(str)
 		if err != nil {
@@ -199,7 +212,17 @@ func (bpkg *BuildPackage) CompilerInfo(
 	}
 
 	bpkg.SourceDirectories, err = bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
-		"pkg.src_dirs", settings)
+		"pkg.source_dirs", settings)
+	util.OneTimeWarningError(err)
+
+	if len(bpkg.SourceDirectories) == 0 {
+		bpkg.SourceDirectories, err = bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
+			"pkg.src_dirs", settings)
+		util.OneTimeWarningError(err)
+	}
+
+	bpkg.SourceFiles, err = bpkg.rpkg.Lpkg.PkgY.GetValStringSlice(
+		"pkg.source_files", settings)
 	util.OneTimeWarningError(err)
 
 	includePaths, err := bpkg.recursiveIncludePaths(b)
@@ -270,7 +293,17 @@ func (bpkg *BuildPackage) publicIncludeDirs(b *Builder) []string {
 		util.OneTimeWarningError(err)
 
 		for _, dir := range inclDirs {
-			incls = append(incls, bp+"/"+dir)
+			repo, path, err := newtutil.ParsePackageString(dir)
+
+			if err != nil {
+				util.OneTimeWarningError(err)
+			}
+
+			if repo != "" {
+				incls = append(incls, "repos/"+repo+"/"+path)
+			} else {
+				incls = append(incls, bp+"/"+dir)
+			}
 		}
 	}
 
