@@ -23,6 +23,7 @@ import (
 	"bufio"
 	"fmt"
 	"io/ioutil"
+	"mynewt.apache.org/newt/newt/cfgv"
 	"os"
 	"path/filepath"
 	"sort"
@@ -59,25 +60,26 @@ type TargetBuilder struct {
 	LoaderList    interfaces.PackageList
 
 	keyFile          string
-	injectedSettings map[string]string
+	injectedSettings *cfgv.Settings
 
 	res *resolve.Resolution
 }
 
 func NewTargetTester(target *target.Target,
 	testPkg *pkg.LocalPackage) (*TargetBuilder, error) {
-
 	if err := target.Validate(testPkg == nil); err != nil {
 		return nil, err
 	}
 
-	bspPkg, err := pkg.NewBspPackage(target.Bsp())
+	bspPkg, err := pkg.NewBspPackage(target.Bsp(), target.GetBspYCfgOverride())
 	if err != nil {
 		return nil, err
 	}
 
+	compilerName := bspPkg.CompilerName
+
 	compilerPkg, err := project.GetProject().ResolvePackage(
-		bspPkg.Repo(), bspPkg.CompilerName)
+		bspPkg.Repo(), compilerName)
 	if err != nil {
 		return nil, err
 	}
@@ -90,7 +92,7 @@ func NewTargetTester(target *target.Target,
 		loaderPkg:        target.Loader(),
 		keyFile:          target.KeyFile,
 		testPkg:          testPkg,
-		injectedSettings: map[string]string{},
+		injectedSettings: cfgv.NewSettings(nil),
 	}
 
 	return t, nil
@@ -111,8 +113,15 @@ func (t *TargetBuilder) NewCompiler(dstDir string, buildProfile string) (
 		buildProfile = t.target.BuildProfile
 	}
 
+	var cfg *cfgv.Settings
+	cfg = nil
+
+	if t.AppBuilder != nil {
+		cfg = t.AppBuilder.cfg.SettingValues()
+	}
+
 	c, err := toolchain.NewCompiler(
-		t.compilerPkg.BasePath(), dstDir, buildProfile)
+		t.compilerPkg.BasePath(), dstDir, buildProfile, cfg)
 
 	return c, err
 }
@@ -186,9 +195,9 @@ func (t *TargetBuilder) ensureResolved() error {
 		//       dependency resolution.
 		//     * The app source files receive "-DSPLIT_[...]=1" command line
 		//       arguments during compilation.
-		t.loaderPkg.InjectedSettings()["SPLIT_LOADER"] = "1"
+		t.loaderPkg.InjectedSettings().Set("SPLIT_LOADER", "1")
 		if t.appPkg != nil {
-			t.appPkg.InjectedSettings()["SPLIT_APPLICATION"] = "1"
+			t.appPkg.InjectedSettings().Set("SPLIT_APPLICATION", "1")
 		}
 
 		// Inject the SPLIT_IMAGE setting into the entire target.  All packages
@@ -282,7 +291,12 @@ func (t *TargetBuilder) validateAndWriteCfg() error {
 	incDir := GeneratedIncludeDir(t.target.FullName())
 	srcDir := GeneratedSrcDir(t.target.FullName())
 
-	if err := syscfg.EnsureWritten(t.res.Cfg, incDir); err != nil {
+	lpkgs := resolve.RpkgSliceToLpkgSlice(t.res.MasterSet.Rpkgs)
+	apis := []string{}
+	for api := range t.res.ApiMap {
+		apis = append(apis, api)
+	}
+	if err := syscfg.EnsureWritten(t.res.Cfg, incDir, lpkgs, apis); err != nil {
 		return err
 	}
 
@@ -292,7 +306,7 @@ func (t *TargetBuilder) validateAndWriteCfg() error {
 
 	// Generate loader sysinit.
 	if t.res.LoaderSet != nil {
-		lpkgs := resolve.RpkgSliceToLpkgSlice(t.res.LoaderSet.Rpkgs)
+		lpkgs = resolve.RpkgSliceToLpkgSlice(t.res.LoaderSet.Rpkgs)
 		if err := t.res.SysinitCfg.EnsureWritten(lpkgs, srcDir,
 			pkg.ShortName(t.target.Package()), true); err != nil {
 
@@ -301,7 +315,7 @@ func (t *TargetBuilder) validateAndWriteCfg() error {
 	}
 
 	// Generate app sysinit.
-	lpkgs := resolve.RpkgSliceToLpkgSlice(t.res.AppSet.Rpkgs)
+	lpkgs = resolve.RpkgSliceToLpkgSlice(t.res.AppSet.Rpkgs)
 	if err := t.res.SysinitCfg.EnsureWritten(lpkgs, srcDir,
 		pkg.ShortName(t.target.Package()), false); err != nil {
 
@@ -310,7 +324,7 @@ func (t *TargetBuilder) validateAndWriteCfg() error {
 
 	// Generate loader sysinit.
 	if t.res.LoaderSet != nil {
-		lpkgs := resolve.RpkgSliceToLpkgSlice(t.res.LoaderSet.Rpkgs)
+		lpkgs = resolve.RpkgSliceToLpkgSlice(t.res.LoaderSet.Rpkgs)
 		if err := t.res.SysdownCfg.EnsureWritten(lpkgs, srcDir,
 			pkg.ShortName(t.target.Package()), true); err != nil {
 
@@ -740,7 +754,7 @@ func (t *TargetBuilder) GetTestPkg() *pkg.LocalPackage {
 }
 
 func (t *TargetBuilder) InjectSetting(key string, value string) {
-	t.injectedSettings[key] = value
+	t.injectedSettings.Set(key, value)
 }
 
 // Calculates the size of a single boot trailer.  This is the amount of flash
