@@ -22,6 +22,7 @@ package pkg
 import (
 	"bytes"
 	"fmt"
+	"mynewt.apache.org/newt/newt/cfgv"
 	"os"
 	"path/filepath"
 	"strings"
@@ -60,7 +61,7 @@ type LocalPackage struct {
 
 	// Extra package-specific settings that don't come from syscfg.  For
 	// example, SELFTEST gets set when the newt test command is used.
-	injectedSettings map[string]string
+	injectedSettings *cfgv.Settings
 
 	// Settings read from pkg.yml.
 	PkgY ycfg.YCfg
@@ -77,7 +78,7 @@ func NewLocalPackage(r *repo.Repo, pkgDir string) *LocalPackage {
 		desc:             &PackageDesc{},
 		repo:             r,
 		basePath:         filepath.ToSlash(filepath.Clean(pkgDir)),
-		injectedSettings: map[string]string{},
+		injectedSettings: cfgv.NewSettings(nil),
 	}
 
 	pkg.PkgY = ycfg.NewYCfg(pkg.PkgYamlPath())
@@ -111,6 +112,10 @@ func (pkg *LocalPackage) BasePath() string {
 	return pkg.basePath
 }
 
+func (pkg *LocalPackage) PkgConfig() *ycfg.YCfg {
+	return &pkg.PkgY
+}
+
 func (pkg *LocalPackage) RelativePath() string {
 	proj := interfaces.GetProject()
 	return strings.TrimPrefix(pkg.BasePath(), proj.Path())
@@ -255,6 +260,7 @@ func (pkg *LocalPackage) Save() error {
 
 	file.WriteString("\n")
 
+	file.WriteString(pkg.sequenceString("pkg.deps"))
 	file.WriteString(pkg.sequenceString("pkg.aflags"))
 	file.WriteString(pkg.sequenceString("pkg.cflags"))
 	file.WriteString(pkg.sequenceString("pkg.cxxflags"))
@@ -367,7 +373,7 @@ func (pkg *LocalPackage) Load() error {
 }
 
 func (pkg *LocalPackage) InitFuncs(
-	settings map[string]string) map[string]interface{} {
+	settings *cfgv.Settings) map[string]interface{} {
 
 	vals, err := pkg.PkgY.GetValStringMap("pkg.init", settings)
 	util.OneTimeWarningError(err)
@@ -377,7 +383,7 @@ func (pkg *LocalPackage) InitFuncs(
 // DownFuncs retrieves the package's shutdown functions.  The returned map has:
 // key=C-function-name, value=numeric-stage.
 func (pkg *LocalPackage) DownFuncs(
-	settings map[string]string) map[string]string {
+	settings *cfgv.Settings) map[string]string {
 
 	vals, err := pkg.PkgY.GetValStringMapString("pkg.down", settings)
 	util.OneTimeWarningError(err)
@@ -385,7 +391,7 @@ func (pkg *LocalPackage) DownFuncs(
 }
 
 func (pkg *LocalPackage) PreBuildCmds(
-	settings map[string]string) map[string]string {
+	settings *cfgv.Settings) map[string]string {
 
 	vals, err := pkg.PkgY.GetValStringMapString("pkg.pre_build_cmds", settings)
 	util.OneTimeWarningError(err)
@@ -393,7 +399,7 @@ func (pkg *LocalPackage) PreBuildCmds(
 }
 
 func (pkg *LocalPackage) PreLinkCmds(
-	settings map[string]string) map[string]string {
+	settings *cfgv.Settings) map[string]string {
 
 	vals, err := pkg.PkgY.GetValStringMapString("pkg.pre_link_cmds", settings)
 	util.OneTimeWarningError(err)
@@ -401,14 +407,14 @@ func (pkg *LocalPackage) PreLinkCmds(
 }
 
 func (pkg *LocalPackage) PostLinkCmds(
-	settings map[string]string) map[string]string {
+	settings *cfgv.Settings) map[string]string {
 
 	vals, err := pkg.PkgY.GetValStringMapString("pkg.post_link_cmds", settings)
 	util.OneTimeWarningError(err)
 	return vals
 }
 
-func (pkg *LocalPackage) InjectedSettings() map[string]string {
+func (pkg *LocalPackage) InjectedSettings() *cfgv.Settings {
 	return pkg.injectedSettings
 }
 
