@@ -22,6 +22,8 @@ package toolchain
 import (
 	"fmt"
 	"io/ioutil"
+	"mynewt.apache.org/newt/newt/cfgv"
+	"mynewt.apache.org/newt/newt/pkg"
 	"os"
 	"path"
 	"path/filepath"
@@ -89,6 +91,7 @@ type Compiler struct {
 	baseDir               string
 	srcDir                string
 	dstDir                string
+	settings              *cfgv.Settings
 
 	// The info to be applied during compilation.
 	info CompilerInfo
@@ -249,7 +252,7 @@ func (ci *CompilerInfo) AddCompilerInfo(newCi *CompilerInfo) {
 }
 
 func NewCompiler(compilerDir string, dstDir string,
-	buildProfile string) (*Compiler, error) {
+	buildProfile string, cfg *cfgv.Settings) (*Compiler, error) {
 
 	c := &Compiler{
 		mutex:           &sync.Mutex{},
@@ -266,7 +269,7 @@ func NewCompiler(compilerDir string, dstDir string,
 	util.StatusMessage(util.VERBOSITY_VERBOSE,
 		"Loading compiler %s, buildProfile %s\n", compilerDir,
 		buildProfile)
-	err := c.load(compilerDir, buildProfile)
+	err := c.load(compilerDir, buildProfile, cfg)
 	if err != nil {
 		return nil, err
 	}
@@ -274,7 +277,19 @@ func NewCompiler(compilerDir string, dstDir string,
 	return c, nil
 }
 
-func loadFlags(yc ycfg.YCfg, settings map[string]string, key string) []string {
+func replaceVal(cfg *cfgv.Settings) func(string) string {
+
+	return func(m string) string {
+		name := m[2 : len(m)-1]
+		if cfg.Exists(name) {
+			return cfg.Get(name)
+		} else {
+			return ""
+		}
+	}
+}
+
+func loadFlags(yc ycfg.YCfg, settings *cfgv.Settings, key string, cfg *cfgv.Settings) []string {
 	flags := []string{}
 
 	rawFlags, err := yc.GetValStringSlice(key, settings)
@@ -291,19 +306,64 @@ func loadFlags(yc ycfg.YCfg, settings map[string]string, key string) []string {
 		}
 	}
 
+	if cfg != nil {
+		for i := range flags {
+			re := regexp.MustCompile(`\$\([A-Z0-9_]+\)`)
+			flags[i] = re.ReplaceAllStringFunc(flags[i], replaceVal(cfg))
+		}
+	}
+
 	return flags
 }
 
-func (c *Compiler) load(compilerDir string, buildProfile string) error {
+func getConfigMap(compilerDir string) (map[string]string, error) {
+	dstMap := make(map[string]string)
+
+	scfg, err := config.ReadFile(compilerDir + "/" + pkg.SYSCFG_YAML_FILENAME)
+	if err != nil {
+		return nil, err
+	}
+
+	for _, setting := range scfg.AllSettings() {
+		aSetting, ok := setting.(map[interface{}]interface{})
+		if ok {
+			for settingName, settingFields := range aSetting {
+				aSettingName := settingName.(string)
+				aSettingFields, ok := settingFields.(map[interface{}]interface{})
+				if ok {
+					for settingField, fieldValue := range aSettingFields {
+						if settingField == "value" {
+							aFieldValue, ok := fieldValue.(string)
+							if ok {
+								dstMap[aSettingName] = aFieldValue
+							}
+						}
+					}
+				}
+			}
+		}
+	}
+
+	return dstMap, nil
+}
+
+func (c *Compiler) load(compilerDir string, buildProfile string, cfg *cfgv.Settings) error {
 	yc, err := config.ReadFile(compilerDir + "/" + COMPILER_FILENAME)
 	if err != nil {
 		return err
 	}
 
-	settings := map[string]string{
+	if cfg == nil {
+		cfgMap, err := getConfigMap(compilerDir)
+		if err == nil {
+			cfg = cfgv.NewSettingsFromMap(cfgMap)
+		}
+	}
+
+	settings := cfgv.NewSettingsFromMap(map[string]string{
 		buildProfile:                  "1",
 		strings.ToUpper(runtime.GOOS): "1",
-	}
+	})
 
 	c.ccPath, err = yc.GetValString("compiler.path.cc", settings)
 	util.OneTimeWarningError(err)
@@ -326,10 +386,10 @@ func (c *Compiler) load(compilerDir string, buildProfile string) error {
 	c.ocPath, err = yc.GetValString("compiler.path.objcopy", settings)
 	util.OneTimeWarningError(err)
 
-	c.lclInfo.Cflags = loadFlags(yc, settings, "compiler.flags")
-	c.lclInfo.CXXflags = loadFlags(yc, settings, "compiler.cxx.flags")
-	c.lclInfo.Lflags = loadFlags(yc, settings, "compiler.ld.flags")
-	c.lclInfo.Aflags = loadFlags(yc, settings, "compiler.as.flags")
+	c.lclInfo.Cflags = loadFlags(yc, settings, "compiler.flags", cfg)
+	c.lclInfo.CXXflags = loadFlags(yc, settings, "compiler.cxx.flags", cfg)
+	c.lclInfo.Lflags = loadFlags(yc, settings, "compiler.ld.flags", cfg)
+	c.lclInfo.Aflags = loadFlags(yc, settings, "compiler.as.flags", cfg)
 
 	c.ldResolveCircularDeps, err = yc.GetValBool(
 		"compiler.ld.resolve_circular_deps", settings)
@@ -500,21 +560,21 @@ func (c *Compiler) GenDepsForFile(file string, compilerType int) error {
 	var cmdName string
 	var flags []string
 	switch compilerType {
-        case COMPILER_TYPE_C:
-                cmdName = c.ccPath
-                flags = c.cflagsStrings()
-        case COMPILER_TYPE_ASM:
-                cmdName = c.asPath
+	case COMPILER_TYPE_C:
+		cmdName = c.ccPath
+		flags = c.cflagsStrings()
+	case COMPILER_TYPE_ASM:
+		cmdName = c.asPath
 
-                // Include both the compiler flags and the assembler flags.
-                // XXX: This is not great.  We don't have a way of specifying compiler
-                // flags without also passing them to the assembler.
-                flags = append(c.cflagsStrings(), c.aflagsStrings()...)
-        case COMPILER_TYPE_CPP:
-                cmdName = c.cppPath
-                flags = append(c.cflagsStrings(), c.cxxflagsStrings()...)
-        default:
-                return util.NewNewtError("Unknown compiler type")
+		// Include both the compiler flags and the assembler flags.
+		// XXX: This is not great.  We don't have a way of specifying compiler
+		// flags without also passing them to the assembler.
+		flags = append(c.cflagsStrings(), c.aflagsStrings()...)
+	case COMPILER_TYPE_CPP:
+		cmdName = c.cppPath
+		flags = append(c.cflagsStrings(), c.cxxflagsStrings()...)
+	default:
+		return util.NewNewtError("Unknown compiler type")
 	}
 
 	srcPath := strings.TrimPrefix(file, c.baseDir+"/")
@@ -666,6 +726,21 @@ func compilerTypeToExts(compilerType int) ([]string, error) {
 	}
 }
 
+func fileNameToCompilerType(filename string) (int, error) {
+	switch filepath.Ext(filename) {
+	case ".c":
+		return COMPILER_TYPE_C, nil
+	case ".s", ".S":
+		return COMPILER_TYPE_ASM, nil
+	case ".cc", ".cpp", ".cxx":
+		return COMPILER_TYPE_CPP, nil
+	case ".a":
+		return COMPILER_TYPE_ARCHIVE, nil
+	default:
+		return -1, util.NewNewtError("Unknown file type for " + filename)
+	}
+}
+
 // Compiles all C files matching the specified file glob.
 func (c *Compiler) CompileC(filename string) error {
 	filename = filepath.ToSlash(filename)
@@ -814,6 +889,21 @@ func (c *Compiler) processEntry(node os.FileInfo, cType int,
 	return entries, err
 }
 
+func (c *Compiler) CollectSingleEntry(filename string) (*CompilerJob, error) {
+	file := filepath.ToSlash(filename)
+	ctype, err := fileNameToCompilerType(file)
+
+	if err != nil {
+		return nil, err
+	}
+
+	return &CompilerJob{
+		Filename:     file,
+		Compiler:     c,
+		CompilerType: ctype,
+	}, nil
+}
+
 func (c *Compiler) RecursiveCollectEntries(cType int,
 	ignDirs []string) ([]CompilerJob, error) {
 
@@ -1184,6 +1274,32 @@ func (c *Compiler) CompileArchiveCmd(archiveFile string,
 	return cmd
 }
 
+func (c *Compiler) CompileArchiveCmdSafe(archiveFile string,
+	objFiles []string) [][]string {
+
+	var cmds [][]string
+
+	objFiles = c.getObjFiles(objFiles)
+
+	for len(objFiles) > 0 {
+		cmd := []string{
+			c.arPath,
+			"rcs",
+			archiveFile,
+		}
+
+		for len(objFiles) > 0 && len(strings.Join(cmd, " ")) < 30000 {
+			var objFile string
+			objFile, objFiles = objFiles[0], objFiles[1:]
+			cmd = append(cmd, objFile)
+		}
+
+		cmds = append(cmds, cmd)
+	}
+
+	return cmds
+}
+
 func linkerScriptFileName(archiveFile string) string {
 	ar_script_name := strings.TrimSuffix(archiveFile, filepath.Ext(archiveFile)) + "_ar.mri"
 	return ar_script_name
@@ -1278,14 +1394,18 @@ func (c *Compiler) CompileArchive(archiveFile string) error {
 		return util.NewNewtError(err.Error())
 	}
 
-	cmd := c.CompileArchiveCmd(archiveFile, objFiles)
-	o, err := util.ShellCommand(cmd, nil)
-	if err != nil {
-		return err
-	}
-	util.StatusMessage(util.VERBOSITY_DEFAULT, "%s", string(o))
+	fullCmd := c.CompileArchiveCmd(archiveFile, objFiles)
 
-	err = writeCommandFile(archiveFile, cmd)
+	cmdSafe := c.CompileArchiveCmdSafe(archiveFile, objFiles)
+	for _, cmd := range cmdSafe {
+		o, err := util.ShellCommand(cmd, nil)
+		if err != nil {
+			return err
+		}
+		util.StatusMessage(util.VERBOSITY_DEFAULT, "%s", string(o))
+	}
+
+	err = writeCommandFile(archiveFile, fullCmd)
 	if err != nil {
 		return err
 	}
